Welcome to django-on-demand’s documentation! — django-on-demand 0.0.1 documentation

# Welcome to django-on-demand’s documentation!

Manage suppliers and consumers in an on-demand marketplace. Think of it like an API to build services like Airbnb, Upwork, or any marketplace where you have suppliers offering a service o product, and consumers searching for specific characteristics of the product or service.

This app provides models and API endpoints to facilitate the implementation of the marketplace.

## Endpoints

- `/search-suppliers`

- `/users/<id>/supplier-profile` (create, update, retrieve)

- `/users/<id>/consumer-profile` (create, update, retrieve)

- `/newest-suppliers`

- `/connection` (create a connection between supplier and consumer, update, terminate)

### Content

- Installation
- Endpoints
  - /search-suppliers
  - /users/<id>/supplier-profile
  - /users/<id>/consumer-profile
  - /newest-suppliers
  - /connection
- Models
- Admin

# Indices and tables

- Index

- Module Index

- Search Page